@@ -114,6 +114,18 @@ def artefacts(tmp_path):
             ],
             "qemu-armv7-kselftest-ipc.yaml",
         ),
+        (
+            [
+                "--device",
+                "qemu-armv7",
+                "--tests",
+                "kselftest-ipc",
+                "--parameters",
+                "KSELFTEST=https://example.com/kselftest.tar.xz",
+                "SKIPFILE=/skipfile.yaml",
+            ],
+            "qemu-armv7-kselftest-ipc-skipfile.yaml",
+        ),
         (
             [
                 "--device",
