@@ -58,6 +58,13 @@ class MorelloBusyBoxPureCap(MorelloTest):
     timeout = 5
 
 
+class MorelloBusyBoxVirtioP9(MorelloTest):
+    devices = ["fvp-morello-busybox"]
+    template = "morello-busybox-virtio.yaml.jinja2"
+    name = "virtiop9"
+    timeout = 5
+
+
 class MorelloBinder(MorelloAndroidTest):
     name = "binder"
     timeout = 34
@@ -106,6 +113,11 @@ class MorelloDvfs(MorelloAndroidTest):
     timeout = 15
 
 
+class MorelloLibPcre(MorelloAndroidTest):
+    name = "libpcre"
+    timeout = 60
+
+
 class MorelloFWTS(MorelloTest):
     name = "fwts"
     timeout = 120
